#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
#' @useDynLib rtrend, .registration = TRUE
#' @importFrom Rcpp sourceCpp
#' 
#' @importFrom graphics abline grid legend
#' @importFrom stats .lm.fit lm acf median na.omit pnorm qnorm
#' @import magrittr
## usethis namespace: end
NULL

.onLoad <- function(libname, pkgname) {
  if (getRversion() >= "2.15.1") {
    utils::globalVariables(
      c(".", ".SD", ".N")
    )
  }
}
